@@ -7,6 +7,8 @@ IMAGE_COLUMN_NAME = tlc.IMAGE
 CLASSIFY_LABEL_COLUMN_NAME = tlc.LABEL
 DETECTION_LABEL_COLUMN_NAME = f"{tlc.BOUNDING_BOXES}.{tlc.BOUNDING_BOX_LIST}.{tlc.LABEL}"
 SEGMENTATION_LABEL_COLUMN_NAME = f"{tlc.SEGMENTATIONS}.{tlc.INSTANCE_PROPERTIES}.{tlc.LABEL}"
+OBB_LABEL_COLUMN_NAME = tlc.ORIENTED_BBS_2D
+POSE_LABEL_COLUMN_NAME = tlc.KEYPOINTS_2D
 PRECISION = "precision"
 PRECISION_SEG = "precision_seg"
 RECALL = "recall"
@@ -25,4 +27,8 @@ DEFAULT_COLLECT_RUN_DESCRIPTION = "Created with model.collect()"
 
 TLC_PREFIX = "3LC://"
 TLC_COLORSTR = colorstr("3lc: ")
-TLC_REQUIRED_VERSION = "2.13.1"
+
+REQUIREMENTS_TO_CHECK = [
+    ("3lc", "tlc"),
+    ("ultralytics", "ultralytics"),
+]
