@@ -22,7 +22,7 @@ from tlc_ultralytics.constants import (
     TLC_COLORSTR,
     TRAINING_PHASE,
 )
-from tlc_ultralytics.engine.utils import _complete_label_column_name
+from tlc_ultralytics.engine.utils import _complete_label_column_name, _handle_deprecated_column_name
 from tlc_ultralytics.settings import Settings
 from tlc_ultralytics.utils import image_embeddings_schema, training_phase_schema
 
@@ -47,12 +47,31 @@ class TLCValidatorMixin(BaseValidator):
         **kwargs,
     ):
         self._run = run
-        self._image_column_name = image_column_name or self._default_image_column_name
-        self._label_column_name = _complete_label_column_name(label_column_name, self._default_label_column_name)
         # Settings can be passed as an argument directly to the validator, or as a keyword from the trainer
         self._settings = settings or kwargs.get("args", {}).pop("settings", None) or Settings()
+
+        self._settings.image_column_name = _handle_deprecated_column_name(
+            image_column_name,
+            self._settings.image_column_name,
+            self._default_image_column_name,
+            column_name="image_column_name",
+        )
+        self._settings.label_column_name = _handle_deprecated_column_name(
+            label_column_name,
+            self._settings.label_column_name,
+            self._default_label_column_name,
+            column_name="label_column_name",
+        )
+        self._settings.label_column_name = _complete_label_column_name(
+            self._settings.label_column_name,
+            self._default_label_column_name,
+        )
+
         self._training = training
 
+        if not training:
+            self._settings.verify(training=False)
+
         # Table is passed when doing validation only, not when training
         self._table = kwargs.get("args", {}).pop("table", None) if not training else None
 
@@ -70,8 +89,8 @@ class TLCValidatorMixin(BaseValidator):
             self.data = self.check_dataset(
                 self.args.data,
                 {self.args.split: self._table} if self._table is not None else None,
-                self._image_column_name,
-                self._label_column_name,
+                self._settings.image_column_name,
+                self._settings.label_column_name,
                 project_name=self._settings.project_name,
                 splits=(self.args.split,),
             )
@@ -91,17 +110,29 @@ class TLCValidatorMixin(BaseValidator):
                 run_name = self._run.url.parts[-1]
                 LOGGER.info(f"{TLC_COLORSTR}Using active run named '{run_name}' in project {self._run.project_name}.")
             else:
+                try:
+                    root_url = self.data[first_split].root
+                except Exception:
+                    root_url = None
+
                 self._run = tlc.init(
                     project_name=project_name,
                     description=self._settings.run_description
                     if self._settings.run_description
                     else DEFAULT_COLLECT_RUN_DESCRIPTION,
                     run_name=self._settings.run_name,
+                    root_url=root_url,
                 )
                 LOGGER.info(
                     f"{TLC_COLORSTR}Created run named '{self._run.url.parts[-1]}' in project {self._run.project_name}."
                 )
 
+        if self.args.task == "pose" and not self._training:
+            table_sigmas = self.data.get("oks_sigmas")
+            if table_sigmas is not None:
+                table_sigmas_rounded = [round(x, 2) for x in table_sigmas]
+                LOGGER.info(f"{TLC_COLORSTR}Using OKS sigmas: {table_sigmas_rounded} from Table for validation")
+
         self.metrics.run_url = self._run.url
 
     def __call__(self, trainer=None, model=None):
@@ -272,8 +303,8 @@ class TLCValidatorMixin(BaseValidator):
         self._final_validation = None
 
     def _write_per_class_metrics_tables(self) -> None:
-        if self.args.task not in ("detect", "segment"):
-            # Per-class metrics currently only supported for detection and segmentation tasks
+        if self.args.task not in ("detect", "segment", "obb"):
+            # Per-class metrics currently only supported for detection, segmentation, and obb tasks
             return
 
         metrics_writer = tlc.MetricsTableWriter(
@@ -298,8 +329,8 @@ class TLCValidatorMixin(BaseValidator):
             {
                 tlc.FOREIGN_TABLE_ID: [0] * num_classes,
                 tlc.LABEL: list(range(num_classes)),
-                NUM_INSTANCES: np.append(self.nt_per_class, self.nt_per_class.sum()),
-                NUM_IMAGES: np.append(self.nt_per_image, self.seen),
+                NUM_INSTANCES: np.append(self.metrics.nt_per_class, self.metrics.nt_per_class.sum()),
+                NUM_IMAGES: np.append(self.metrics.nt_per_image, self.seen),
                 **self._generate_per_class_metrics(),
             }
         )
@@ -316,7 +347,9 @@ class TLCValidatorMixin(BaseValidator):
     def _per_class_metrics_schemas(self):
         metrics_schemas = {
             TRAINING_PHASE: training_phase_schema(),
-            tlc.FOREIGN_TABLE_ID: tlc.ForeignTableIdSchema(self.dataloader.dataset.table.url.to_str()),
+            tlc.FOREIGN_TABLE_ID: tlc.ForeignTableIdSchema(
+                self.dataloader.dataset.table.url.to_relative(self._run.url / "metrics").to_str(),
+            ),
             tlc.LABEL: tlc.CategoricalLabel("class", {**self.names, self.nc: "all"}).schema,
             NUM_IMAGES: tlc.Schema(
                 value=tlc.Int32Value(),
@@ -383,9 +416,9 @@ class TLCValidatorMixin(BaseValidator):
         for i in range(self.nc):
             if i in self.metrics.ap_class_index:
                 class_results = self.metrics.class_result(np.where(self.metrics.ap_class_index == i)[0][0])
-                if self.args.task == "detect":
+                if self.args.task in ("detect", "obb"):
                     p, r, ap50, ap5095 = class_results
-                else:
+                else:  # seg and pose
                     p, r, ap50, ap5095, p_seg, r_seg, ap50_seg, ap5095_seg = class_results
             else:
                 p, r, ap50, ap5095 = 0.0, 0.0, 0.0, 0.0
@@ -404,9 +437,9 @@ class TLCValidatorMixin(BaseValidator):
                 mAP50_95s_seg[i] = ap5095_seg
 
         mean_results = self.metrics.mean_results()
-        if self.args.task == "detect":
+        if self.args.task in ("detect", "obb"):
             all_p, all_r, all_mAP50, all_mAP50_95 = mean_results
-        else:
+        else:  # seg and pose
             (
                 all_p,
                 all_r,
