@@ -1,12 +1,12 @@
-from .check_version import check_tlc_version
+from .check_requirements import check_requirements
 from .dataset import check_tlc_dataset, parse_3lc_yaml_file
 from .embeddings import reduce_embeddings
 from .sampler import create_sampler
 from .schemas import image_embeddings_schema, training_phase_schema
 
 __all__ = (
+    "check_requirements",
     "check_tlc_dataset",
-    "check_tlc_version",
     "create_sampler",
     "get_table_value_map",
     "image_embeddings_schema",
